@@ -11,6 +11,7 @@ import (
 	"fmt"
 	"io"
 	"io/fs"
+	"log/slog"
 	"net/http"
 	"net/url"
 	"os"
@@ -19,6 +20,7 @@ import (
 	"path/filepath"
 	"regexp"
 	"runtime"
+	"slices"
 	"sort"
 	"strings"
 	"sync"
@@ -28,13 +30,10 @@ import (
 
 	"github.com/coreos/go-semver/semver"
 	"github.com/mitchellh/copystructure"
-	"github.com/rs/zerolog"
-	"github.com/rs/zerolog/log"
-	"golang.org/x/exp/maps"
-	"golang.org/x/exp/slices"
 
 	"github.com/twpayne/chezmoi/v2/internal/chezmoierrors"
 	"github.com/twpayne/chezmoi/v2/internal/chezmoilog"
+	"github.com/twpayne/chezmoi/v2/internal/chezmoimaps"
 )
 
 // An ExternalType is a type of external source.
@@ -123,7 +122,7 @@ type SourceState struct {
 	remove                  *patternSet
 	interpreters            map[string]*Interpreter
 	httpClient              *http.Client
-	logger                  *zerolog.Logger
+	logger                  *slog.Logger
 	version                 semver.Version
 	mode                    Mode
 	defaultTemplateDataFunc func() map[string]any
@@ -194,7 +193,7 @@ func WithInterpreters(interpreters map[string]*Interpreter) SourceStateOption {
 }
 
 // WithLogger sets the logger.
-func WithLogger(logger *zerolog.Logger) SourceStateOption {
+func WithLogger(logger *slog.Logger) SourceStateOption {
 	return func(s *SourceState) {
 		s.logger = logger
 	}
@@ -290,7 +289,7 @@ func NewSourceState(options ...SourceStateOption) *SourceState {
 		ignore:               newPatternSet(),
 		remove:               newPatternSet(),
 		httpClient:           http.DefaultClient,
-		logger:               &log.Logger,
+		logger:               slog.Default(),
 		readTemplateData:     true,
 		readTemplates:        true,
 		priorityTemplateData: make(map[string]any),
@@ -338,7 +337,7 @@ func (s *SourceState) Add(
 	options *AddOptions,
 ) error {
 	// Filter out excluded and ignored paths.
-	destAbsPaths := AbsPaths(maps.Keys(destAbsPathInfos))
+	destAbsPaths := AbsPaths(chezmoimaps.Keys(destAbsPathInfos))
 	sort.Sort(destAbsPaths)
 	n := 0
 	for _, destAbsPath := range destAbsPaths {
@@ -1532,7 +1531,7 @@ func (s *SourceState) getExternalDataRaw(
 	if err != nil {
 		return nil, err
 	}
-	resp, err := chezmoilog.LogHTTPRequest(s.logger, s.httpClient, req)
+	resp, err := chezmoilog.LogHTTPRequest(ctx, s.logger, s.httpClient, req)
 	if err != nil {
 		return nil, err
 	}
@@ -1644,7 +1643,7 @@ func (s *SourceState) getExternalData(
 		cmd := exec.Command(external.Filter.Command, external.Filter.Args...) //nolint:gosec
 		cmd.Stdin = bytes.NewReader(data)
 		cmd.Stderr = os.Stderr
-		data, err = chezmoilog.LogCmdOutput(cmd)
+		data, err = chezmoilog.LogCmdOutput(s.logger, cmd)
 		if err != nil {
 			return nil, fmt.Errorf("%s: %s: %w", externalRelPath, external.URL, err)
 		}
@@ -1855,9 +1854,12 @@ func (s *SourceState) newModifyTargetStateEntryFunc(
 
 			// Run the modifier on the current contents.
 			cmd := interpreter.ExecCommand(tempFile.Name())
+			cmd.Env = append(os.Environ(),
+				"CHEZMOI_SOURCE_FILE="+sourceRelPath.String(),
+			)
 			cmd.Stdin = bytes.NewReader(currentContents)
 			cmd.Stderr = os.Stderr
-			contents, err = chezmoilog.LogCmdOutput(cmd)
+			contents, err = chezmoilog.LogCmdOutput(s.logger, cmd)
 			return
 		}
 		return &TargetStateFile{
@@ -1911,6 +1913,7 @@ func (s *SourceState) newScriptTargetStateEntryFunc(
 			sourceAttr: SourceAttr{
 				Condition: fileAttr.Condition,
 			},
+			sourceRelPath: sourceRelPath,
 		}, nil
 	}
 }
