@@ -62,11 +62,7 @@ func TestBoolInputModel(t *testing.T) {
 		},
 	} {
 		t.Run(tc.name, func(t *testing.T) {
-			actualModel := testRunModelWithInput(
-				t,
-				NewBoolInputModel("prompt", tc.defaultValue),
-				tc.input,
-			)
+			actualModel := testRunModelWithInput(t, NewBoolInputModel("prompt", tc.defaultValue), tc.input)
 			assert.Equal(t, tc.expectedCanceled, actualModel.Canceled())
 			assert.Equal(t, tc.expectedValue, actualModel.Value())
 		})
