@@ -4,6 +4,7 @@ package cmd
 import (
 	"errors"
 	"fmt"
+	"log/slog"
 	"os"
 	"os/exec"
 	"regexp"
@@ -12,7 +13,6 @@ import (
 	"strings"
 
 	"github.com/charmbracelet/glamour"
-	"github.com/rs/zerolog"
 	"github.com/spf13/cobra"
 	"go.etcd.io/bbolt"
 
@@ -97,13 +97,13 @@ func init() {
 	}
 }
 
-// MarshalZerologObject implements
-// github.com/rs/zerolog.LogObjectMarshaler.MarshalZerologObject.
-func (v VersionInfo) MarshalZerologObject(e *zerolog.Event) {
-	e.Str("version", v.Version)
-	e.Str("commit", v.Commit)
-	e.Str("date", v.Date)
-	e.Str("builtBy", v.BuiltBy)
+func (v VersionInfo) LogValue() slog.Value {
+	return slog.GroupValue(
+		slog.String("version", v.Version),
+		slog.String("commit", v.Commit),
+		slog.String("date", v.Date),
+		slog.String("builtBy", v.BuiltBy),
+	)
 }
 
 // Main runs chezmoi and returns an exit code.
