@@ -8,6 +8,7 @@ import (
 	"errors"
 	"fmt"
 	"io/fs"
+	"log/slog"
 	"net/http"
 	"os"
 	"os/exec"
@@ -19,14 +20,14 @@ import (
 	"time"
 
 	"github.com/coreos/go-semver/semver"
-	"github.com/google/go-github/v58/github"
+	"github.com/google/go-github/v59/github"
 	"github.com/spf13/cobra"
 	"github.com/twpayne/go-shell"
 	"github.com/twpayne/go-xdg/v6"
 
 	"github.com/twpayne/chezmoi/v2/internal/chezmoi"
+	"github.com/twpayne/chezmoi/v2/internal/chezmoigit"
 	"github.com/twpayne/chezmoi/v2/internal/chezmoilog"
-	"github.com/twpayne/chezmoi/v2/internal/git"
 )
 
 // A checkResult is the result of a check.
@@ -265,7 +266,7 @@ func (c *Config) runDoctorCmd(cmd *cobra.Command, args []string) error {
 		&binaryCheck{
 			name:        "age-command",
 			binaryname:  c.Age.Command,
-			versionArgs: []string{"-version"},
+			versionArgs: []string{"--version"},
 			versionRx:   regexp.MustCompile(`(\d+\.\d+\.\d+\S*)`),
 			ifNotSet:    checkResultWarning,
 			ifNotExist:  checkResultInfo,
@@ -480,7 +481,7 @@ func (c *binaryCheck) Run(system chezmoi.System, homeDirAbsPath chezmoi.AbsPath)
 	}
 
 	cmd := exec.Command(pathAbsPath.String(), c.versionArgs...) //nolint:gosec
-	output, err := chezmoilog.LogCmdCombinedOutput(cmd)
+	output, err := chezmoilog.LogCmdCombinedOutput(slog.Default(), cmd)
 	if err != nil {
 		return checkResultFailed, err.Error()
 	}
@@ -583,7 +584,7 @@ func (c *dirCheck) Run(system chezmoi.System, homeDirAbsPath chezmoi.AbsPath) (c
 			gitStatus = gitStatusError
 			break
 		}
-		switch status, err := git.ParseStatusPorcelainV2(output); {
+		switch status, err := chezmoigit.ParseStatusPorcelainV2(output); {
 		case err != nil:
 			gitStatus = gitStatusError
 		case status.Empty():
