@@ -5,10 +5,10 @@ import (
 	"fmt"
 	"os"
 	"os/exec"
+	"slices"
 	"strings"
 
 	"github.com/coreos/go-semver/semver"
-	"golang.org/x/exp/slices"
 
 	"github.com/twpayne/chezmoi/v2/internal/chezmoilog"
 )
@@ -96,7 +96,7 @@ func (c *Config) vltOutput(args []string) ([]byte, error) {
 	cmd.Dir = c.DestDirAbsPath.String()
 	cmd.Stdin = os.Stdin
 	cmd.Stderr = os.Stderr
-	output, err := chezmoilog.LogCmdOutput(cmd)
+	output, err := chezmoilog.LogCmdOutput(c.logger, cmd)
 	if err != nil {
 		return nil, newCmdOutputError(cmd, output, err)
 	}
