@@ -52,6 +52,11 @@ func (c *Config) newMackupCmd() *cobra.Command {
 			requiresSourceDirectory,
 		),
 	}
+	mackupAddCmdPersistentFlags := mackupAddCmd.PersistentFlags()
+	mackupAddCmdPersistentFlags.Var(&c.Add.Secrets, "secrets", "Scan for secrets when adding unencrypted files")
+	if err := mackupAddCmd.RegisterFlagCompletionFunc("secrets", severityFlagCompletionFunc); err != nil {
+		panic(err)
+	}
 	mackupCmd.AddCommand(mackupAddCmd)
 
 	// FIXME add other subcommands like
@@ -138,8 +143,7 @@ func (c *Config) mackupApplicationsDir() (chezmoi.AbsPath, error) {
 			continue
 		}
 		mackupApplicationsDirAbsPath := libDirAbsPath.JoinString(dirEntry.Name(), "site-packages", "mackup", "applications")
-		if fileInfo, err := c.baseSystem.Stat(mackupApplicationsDirAbsPath); err == nil &&
-			fileInfo.IsDir() {
+		if fileInfo, err := c.baseSystem.Stat(mackupApplicationsDirAbsPath); err == nil && fileInfo.IsDir() {
 			return mackupApplicationsDirAbsPath, nil
 		}
 	}
