@@ -4,11 +4,13 @@ import (
 	"errors"
 	"fmt"
 	"io/fs"
+	"log/slog"
 	"strings"
 
 	"github.com/spf13/cobra"
 
 	"github.com/twpayne/chezmoi/v2/internal/chezmoi"
+	"github.com/twpayne/chezmoi/v2/internal/chezmoilog"
 )
 
 type statusCmdConfig struct {
@@ -55,12 +57,12 @@ func (c *Config) newStatusCmd() *cobra.Command {
 func (c *Config) runStatusCmd(cmd *cobra.Command, args []string) error {
 	builder := strings.Builder{}
 	preApplyFunc := func(targetRelPath chezmoi.RelPath, targetEntryState, lastWrittenEntryState, actualEntryState *chezmoi.EntryState) error {
-		c.logger.Info().
-			Stringer("targetRelPath", targetRelPath).
-			Object("targetEntryState", targetEntryState).
-			Object("lastWrittenEntryState", lastWrittenEntryState).
-			Object("actualEntryState", actualEntryState).
-			Msg("statusPreApplyFunc")
+		c.logger.Info("statusPreApplyFunc",
+			chezmoilog.Stringer("targetRelPath", targetRelPath),
+			slog.Any("targetEntryState", targetEntryState),
+			slog.Any("lastWrittenEntryState", lastWrittenEntryState),
+			slog.Any("actualEntryState", actualEntryState),
+		)
 
 		var (
 			x = ' '
